@@ -55,6 +55,15 @@ def GetProject():
   return properties.VALUES.core.project.Get(required=True)
 
 
+def _GetBaseImagePath(image, is_distroless=False):
+  """Returns full the image path of the given image."""
+  if not is_distroless:
+    return (
+        f'gcr.io/dataflow-templates-base/{image}-template-launcher-base:latest'
+    )
+  return f'gcr.io/dataflow-templates-base/{image}-template-launcher-base-distroless:latest'
+
+
 class Jobs:
   """The Jobs set of Dataflow API functions."""
 
@@ -434,18 +443,15 @@ class Templates:
   SDK_INFO = GetMessagesModule().SDKInfo
   SDK_LANGUAGE = GetMessagesModule().SDKInfo.LanguageValueValuesEnum
   CONTAINER_SPEC = GetMessagesModule().ContainerSpec
-  FLEX_TEMPLATE_JAVA11_BASE_IMAGE = ('gcr.io/dataflow-templates-base/'
-                                     'java11-template-launcher-base:latest')
-  FLEX_TEMPLATE_JAVA17_BASE_IMAGE = ('gcr.io/dataflow-templates-base/'
-                                     'java17-template-launcher-base:latest')
-  FLEX_TEMPLATE_JAVA21_BASE_IMAGE = ('gcr.io/dataflow-templates-base/'
-                                     'java21-template-launcher-base:latest')
-  FLEX_TEMPLATE_JAVA8_BASE_IMAGE = ('gcr.io/dataflow-templates-base/'
-                                    'java8-template-launcher-base:latest')
-  FLEX_TEMPLATE_PYTHON3_BASE_IMAGE = ('gcr.io/dataflow-templates-base/'
-                                      'python3-template-launcher-base:latest')
-  FLEX_TEMPLATE_GO_BASE_IMAGE = ('gcr.io/dataflow-templates-base/'
-                                 'go-template-launcher-base:latest')
+  FLEX_TEMPLATE_JAVA11_BASE_IMAGE = _GetBaseImagePath('java11')
+  FLEX_TEMPLATE_JAVA17_BASE_IMAGE = _GetBaseImagePath('java17')
+  FLEX_TEMPLATE_JAVA21_BASE_IMAGE = _GetBaseImagePath('java21')
+  FLEX_TEMPLATE_JAVA11_DISTROLESS_BASE_IMAGE = _GetBaseImagePath('java11', True)
+  FLEX_TEMPLATE_JAVA17_DISTROLESS_BASE_IMAGE = _GetBaseImagePath('java17', True)
+  FLEX_TEMPLATE_JAVA21_DISTROLESS_BASE_IMAGE = _GetBaseImagePath('java21', True)
+  FLEX_TEMPLATE_PYTHON3_BASE_IMAGE = _GetBaseImagePath('python3')
+  FLEX_TEMPLATE_GO_BASE_IMAGE = _GetBaseImagePath('go')
+  FLEX_TEMPLATE_GO_DISTROLESS_BASE_IMAGE = _GetBaseImagePath('go', True)
   YAML_TEMPLATE_GCS_LOCATION = (
       'gs://dataflow-templates-{}/latest/flex/Yaml_Template'
   )
@@ -491,6 +497,11 @@ class Templates:
     ).RuntimeEnvironment.IpConfigurationValueValuesEnum
     ip_private = ip_configuration_enum.WORKER_IP_PRIVATE
     ip_configuration = ip_private if template_args.disable_public_ips else None
+    user_labels_value = GetMessagesModule(
+    ).RuntimeEnvironment.AdditionalUserLabelsValue
+    user_labels_list = Templates.__ConvertDictArguments(
+        template_args.additional_user_labels,
+        user_labels_value)
 
     body = Templates.CREATE_REQUEST(
         gcsPath=template_args.gcs_location,
@@ -510,6 +521,9 @@ class Templates:
             workerRegion=template_args.worker_region,
             workerZone=template_args.worker_zone,
             enableStreamingEngine=template_args.enable_streaming_engine,
+            additionalUserLabels=user_labels_value(
+                additionalProperties=user_labels_list)
+            if user_labels_list else None,
             additionalExperiments=(
                 template_args.additional_experiments
                 if template_args.additional_experiments else
@@ -697,13 +711,24 @@ class Templates:
         'rm -rf /var/lib/apt/lists/*',
     ]
 
-    env['FLEX_TEMPLATE_PYTHON_PY_FILE'] = '/template/{}'.format(
-        (env['FLEX_TEMPLATE_PYTHON_PY_FILE']))
+    env['FLEX_TEMPLATE_PYTHON_PY_FILE'] = (
+        f'/template/{env["FLEX_TEMPLATE_PYTHON_PY_FILE"]}'
+    )
+    if 'FLEX_TEMPLATE_PYTHON_EXTRA_PACKAGES' in env:
+      env['FLEX_TEMPLATE_PYTHON_EXTRA_PACKAGES'] = (
+          f'/template/{env["FLEX_TEMPLATE_PYTHON_EXTRA_PACKAGES"]}'
+      )
+      commands.append(
+          f'pip install {env["FLEX_TEMPLATE_PYTHON_EXTRA_PACKAGES"]}'
+      )
     if 'FLEX_TEMPLATE_PYTHON_REQUIREMENTS_FILE' in env:
-      env['FLEX_TEMPLATE_PYTHON_REQUIREMENTS_FILE'] = '/template/{}'.format(
-          env['FLEX_TEMPLATE_PYTHON_REQUIREMENTS_FILE'])
-      commands.append('pip install --no-cache-dir -U -r {}'.format(
-          env['FLEX_TEMPLATE_PYTHON_REQUIREMENTS_FILE']))
+      env['FLEX_TEMPLATE_PYTHON_REQUIREMENTS_FILE'] = (
+          f'/template/{env["FLEX_TEMPLATE_PYTHON_REQUIREMENTS_FILE"]}'
+      )
+      commands.append(
+          'pip install --no-cache-dir -U -r'
+          f' {env["FLEX_TEMPLATE_PYTHON_REQUIREMENTS_FILE"]}'
+      )
       commands.append(
           '(pip check || (e=$?; echo "Building a container with incompatible'
           ' dependencies is prevented by default. If you are sure you want to'
@@ -712,8 +737,9 @@ class Templates:
           ' exit $e))'
       )
     if 'FLEX_TEMPLATE_PYTHON_SETUP_FILE' in env:
-      env['FLEX_TEMPLATE_PYTHON_SETUP_FILE'] = '/template/{}'.format(
-          env['FLEX_TEMPLATE_PYTHON_SETUP_FILE'])
+      env['FLEX_TEMPLATE_PYTHON_SETUP_FILE'] = (
+          f'/template/{env["FLEX_TEMPLATE_PYTHON_SETUP_FILE"]}'
+      )
 
     envs = ['ENV {}={}'.format(k, v) for k, v in sorted(env.items())]
     env_list = '\n'.join(envs)
@@ -931,12 +957,24 @@ class Templates:
       return Templates.FLEX_TEMPLATE_JAVA17_BASE_IMAGE
     elif flex_template_base_image == 'JAVA21':
       return Templates.FLEX_TEMPLATE_JAVA21_BASE_IMAGE
+    elif flex_template_base_image == 'JAVA11_DISTROLESS':
+      return Templates.FLEX_TEMPLATE_JAVA11_DISTROLESS_BASE_IMAGE
+    elif flex_template_base_image == 'JAVA17_DISTROLESS':
+      return Templates.FLEX_TEMPLATE_JAVA17_DISTROLESS_BASE_IMAGE
+    elif flex_template_base_image == 'JAVA21_DISTROLESS':
+      return Templates.FLEX_TEMPLATE_JAVA21_DISTROLESS_BASE_IMAGE
     elif flex_template_base_image == 'JAVA8':
-      return Templates.FLEX_TEMPLATE_JAVA8_BASE_IMAGE
+      log.warning(
+          'JAVA8 is deprecated and redirected to JAVA11. This option '
+          'will be removed in a future release'
+      )
+      return Templates.FLEX_TEMPLATE_JAVA11_BASE_IMAGE
     elif flex_template_base_image == 'PYTHON3':
       return Templates.FLEX_TEMPLATE_PYTHON3_BASE_IMAGE
     elif flex_template_base_image == 'GO':
       return Templates.FLEX_TEMPLATE_GO_BASE_IMAGE
+    elif flex_template_base_image == 'GO_DISTROLESS':
+      return Templates.FLEX_TEMPLATE_GO_DISTROLESS_BASE_IMAGE
     return flex_template_base_image
 
   @staticmethod
@@ -1292,7 +1330,12 @@ class Templates:
                     .additional_experiments else []),
                 additionalUserLabels=Templates.FLEX_TEMPLATE_USER_LABELS_VALUE(
                     additionalProperties=user_labels_list
-                ) if user_labels_list else None),
+                ) if user_labels_list else None,
+                additionalPipelineOptions=(
+                    template_args.additional_pipeline_options
+                    if template_args.additional_pipeline_options
+                    else []
+                )),
             update=streaming_update,
             transformNameMappings=transform_mappings,
             parameters=Templates.FLEX_TEMPLATE_PARAMETERS_VALUE(
