@@ -21,7 +21,6 @@ import os
 import re
 import socket
 import tempfile
-import uuid
 
 from googlecloudsdk.command_lib.storage import path_util
 from googlecloudsdk.command_lib.storage.diagnose import diagnostic
@@ -33,7 +32,7 @@ from googlecloudsdk.core.util import files
 import requests
 
 
-_CORE_CHECK_NAME = 'Direct Connectivity Upload'
+_CORE_CHECK_NAME = 'Direct Connectivity Call'
 _SUCCESS = 'Success.'
 
 
@@ -58,8 +57,7 @@ def _check_zone_prefix(region, zone):
 
 
 def _exec_and_return_stdout(command):
-  """Returns standard output from executing gcloud command."""
-  command = execution_utils.ArgsForGcloud() + command
+  """Returns standard output from executing a command."""
   out = io.StringIO()
   execution_utils.Exec(
       command,
@@ -69,6 +67,25 @@ def _exec_and_return_stdout(command):
   return out.getvalue().strip()
 
 
+def _exec_gcloud_and_return_stdout(command_args):
+  """Returns standard output from executing gcloud command."""
+  command = execution_utils.ArgsForGcloud() + command_args
+  return _exec_and_return_stdout(command)
+
+
+def _get_zone():
+  """Gets the zone of the VM from the Metadata service."""
+  response = requests.get(
+      # gcloud-disable-gdu-domain
+      'http://metadata.google.internal/computeMetadata/v1/instance/zone',
+      headers={'Metadata-Flavor': 'Google'},
+      timeout=5,
+  )
+  if response.status_code == 200:
+    return response.text.strip().rsplit('/', 1)[-1]
+  return ''
+
+
 def _log_running_check(check_name):
   log.info('Running Check: {}'.format(check_name))
 
@@ -84,7 +101,6 @@ class DirectConnectivityDiagnostic(diagnostic.Diagnostic):
     """Initializes the Direct Connectivity Diagnostic."""
     self._bucket_resource = bucket_resource
     self._cleaned_up = False
-    self._object_path = 'direct_connectivity_diagnostics_' + str(uuid.uuid4())
     self._process_count = 1
     self._results = []
     self._retain_logs = bool(logs_path)
@@ -109,9 +125,6 @@ class DirectConnectivityDiagnostic(diagnostic.Diagnostic):
     """Restores environment variables and cleans up temporary cloud object."""
     if not self._cleaned_up:
       super(DirectConnectivityDiagnostic, self)._post_process()
-      self._clean_up_objects(
-          self._bucket_resource.storage_url.url_string, self._object_path
-      )
       self._cleaned_up = True
 
   def _generic_check_for_string_in_logs(
@@ -125,9 +138,8 @@ class DirectConnectivityDiagnostic(diagnostic.Diagnostic):
           return True
     return False
 
-  def _check_core_upload(self):
-    """Returns true if can upload object over Direct Connectivity infra."""
-    self._set_parallelism_env_vars()
+  def _check_core_buckets_describe_call(self):
+    """Returns true if get bucket success over Direct Connectivity infra."""
     self._set_env_variable('ATTEMPT_DIRECT_PATH', 1)
     self._set_env_variable(
         'CLOUDSDK_STORAGE_PREFERRED_API', 'grpc_with_json_fallback'
@@ -139,15 +151,14 @@ class DirectConnectivityDiagnostic(diagnostic.Diagnostic):
       command = execution_utils.ArgsForGcloud() + [
           '--verbosity=debug',
           'storage',
-          'cp',
-          '-',
-          self._bucket_resource.storage_url.join(self._object_path).url_string,
+          'buckets',
+          'describe',
+          self._bucket_resource.storage_url.url_string,
       ]
 
       return_code = execution_utils.Exec(
           command,
           err_func=file_writer.write,
-          in_str=self._generate_random_string(length=1),
           no_exit=True,
       )
 
@@ -155,7 +166,7 @@ class DirectConnectivityDiagnostic(diagnostic.Diagnostic):
       with files.FileReader(self._logs_path) as file_reader:
         for line in file_reader:
           if re.search(
-              r'(?:\[ipv6:(?:%5B)?2001:4860:80[4-7].+\])?(?:\[ipv4:(?:%5B)?34\.126.+\])?',
+              r'(?:\[ipv6:(?:%5B)?2001:4860:80[4-7].+\])|(?:\[ipv4:(?:%5B)?34\.126.+\])',
               line,
           ):
             return _SUCCESS
@@ -205,7 +216,7 @@ class DirectConnectivityDiagnostic(diagnostic.Diagnostic):
         # gcloud-disable-gdu-domain
     ) + _get_ips('directpath-pa.googleapis.com', 'Traffic Director')
     firewall_response = json.loads(
-        _exec_and_return_stdout(
+        _exec_gcloud_and_return_stdout(
             ['compute', 'firewall-rules', 'list', '--format=json']
         )
     )
@@ -273,12 +284,12 @@ class DirectConnectivityDiagnostic(diagnostic.Diagnostic):
       return (
           f'Found bucket "{self._bucket_resource}" is in a dual-region. Ensure '
           f'VM "{socket.gethostname()}" is in one of the regions covered by '
-          f'the dual-region by looking up the dual-region '
+          'the dual-region by looking up the dual-region '
           f'{_get_region_string_or_not_found(self._bucket_resource.location)} '
-          f'in the following table: '
-          f'https://cloud.google.com/storage/docs/locations#predefined '
+          'in the following table: '
+          'https://cloud.google.com/storage/docs/locations#predefined '
           f'VM zone {_get_region_string_or_not_found(self._vm_zone)} should '
-          f'start with one of the regions covered by the dual-region '
+          'start with one of the regions covered by the dual-region '
           f'{_get_region_string_or_not_found(self._bucket_resource.location)}.'
       )
     # For other region types, the substring check is sufficient.
@@ -295,7 +306,7 @@ class DirectConnectivityDiagnostic(diagnostic.Diagnostic):
     """Checks if VM has a service account."""
     if not self._vm_zone:
       return 'Found no VM zone and, therefore, could not check service account.'
-    service_accounts = _exec_and_return_stdout([
+    service_accounts = _exec_gcloud_and_return_stdout([
         'compute',
         'instances',
         'describe',
@@ -320,30 +331,18 @@ class DirectConnectivityDiagnostic(diagnostic.Diagnostic):
     )
 
     _log_running_check(_CORE_CHECK_NAME)
-    res = self._check_core_upload()
     self._results.append(
         diagnostic.DiagnosticOperationResult(
             name=_CORE_CHECK_NAME,
-            result=res,
+            result=self._check_core_buckets_describe_call(),
             payload_description=(
-                'Able to upload object to bucket using Direct'
+                'Able to get bucket metadata using Direct'
                 ' Connectivity network path.'
             ),
         )
     )
-    if res == _SUCCESS:
-      if not self._retain_logs and os.path.exists(self._logs_path):
-        os.remove(self._logs_path)
-      self._clean_up()
-      return
 
-    self._vm_zone = _exec_and_return_stdout([
-        'compute',
-        'instances',
-        'list',
-        '--filter=name:{}'.format(socket.gethostname()),
-        '--format=table[csv,no-heading](zone)',
-    ])
+    self._vm_zone = _get_zone()
 
     for check, name, description in [
         (
@@ -383,10 +382,8 @@ class DirectConnectivityDiagnostic(diagnostic.Diagnostic):
             self._check_bucket_region,
             'Bucket Region',
             (
-                'Direct Connectivity supports all bucket region types, but only'
-                ' data with replicas in the same region as the VM will be'
-                ' accessible. Consider co-locating the bucket and VM in the'
-                ' same region.'
+                'To get the best performance, the bucket should have a replica'
+                ' in the same region as the VM.'
             ),
         ),
         (
