@@ -399,8 +399,6 @@ class AlphaDeploy(Deploy):
   @classmethod
   def Args(cls, parser):
     cls.CommonArgs(parser)
-    flags.AddMaxSurgeFlag(parser, resource_kind='worker')
-    flags.AddMaxUnavailableFlag(parser, resource_kind='worker')
     flags.AddWorkerPoolMinInstancesFlag(parser)
     flags.AddWorkerPoolMaxInstancesFlag(parser)
     flags.AddGpuTypeFlag(parser)
